@@ -1,6 +1,7 @@
 /**
  ** Simple entropy harvester based upon the havege RNG
  **
+ ** Copyright 2018-2020 Jirka Hladky hladky DOT jiri AT gmail DOT com
  ** Copyright 2009-2014 Gary Wuertz gary@issiweb.com
  ** Copyright 2011-2012 BenEleventh Consulting manolson@beneleventh.com
  **
@@ -30,7 +31,7 @@ extern "C" {
  * header/package version as a numeric major, minor, patch triple. See havege_version()
  * below for useage.
  */
-#define  HAVEGE_PREP_VERSION  "1.9.8"
+#define  HAVEGE_PREP_VERSION  "1.9.11"
 /**
  * Basic types
  */
@@ -238,6 +239,14 @@ typedef enum {
  *                        H_NOINIT
  */
 H_PTR       havege_create(H_PARAMS *params);
+
+/**
+ * haveger_create() remembers parent pid and uses it to identify deallocating thread.
+ * daemonize() forks parent and effectively loses parent thread.
+ * havege_reparent(void) allows recovering new parent pid before havege_run() is started.
+ */
+void        havege_reparent(H_PTR hptr);
+
 /**
  * Frees all allocated anchor resources. If the multi-core option is used, this
  * method should be called from a signal handler to prevent zombie processes.
